@@ -1,4 +1,4 @@
-if [ ! -f /etc/X11/system.XWinrc ]
+if [ ! -e /etc/X11/system.XWinrc ]
 then
     /usr/bin/mkdir -p /etc/X11
     /usr/bin/cp /etc/defaults/etc/X11/system.XWinrc /etc/X11/system.XWinrc
